netapp_ontap.models.storage_port_cable API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_port_cable`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StoragePortCableSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StoragePortCable object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `identifier: str GET POST PATCH`

    The identifier field of the storage_port_cable.

    Example: 500a0980000b6c3f-50000d1703544b80

  `length: str GET POST PATCH`

    The length field of the storage_port_cable.

    Example: 2m

  `part_number: str GET POST PATCH`

    The part_number field of the storage_port_cable.

    Example: 112-00431+A0

  `serial_number: str GET POST PATCH`

    The serial_number field of the storage_port_cable.

    Example: 616930439

  `transceiver: str GET POST PATCH`

    The transceiver field of the storage_port_cable.

    Valid choices:

    - qsfp
    - qsfp_plus
    - qsfp28
    - mini_sas_hd
    - sfp
  `vendor: str GET POST PATCH`

    The vendor field of the storage_port_cable.

    Example: Molex Inc.